@@ -20,15 +20,17 @@
 #include "config.h"
 #endif
 
-#include <libgnome/gnome-i18n.h>
+/* Allow deprecated for the gnome_entry and gnome_file_entry widget */
+#undef GTK_DISABLE_DEPRECATED
+#undef GNOME_DISABLE_DEPRECATED
+
+#include <glib/gi18n.h>
 #include "bookmarks-import-druid.h"
 #include "bookmarks-io.h"
 #include "bookmarks-tree-model.h"
 #include "bookmarks-tree-view.h"
 #include "bookmarks-util.h"
 #include "xbel.h"
-#include "gul-gobject-misc.h"
-#include "gul-state.h"
 #include <libgnomeui/gnome-druid.h>
 #include <libgnomeui/gnome-druid-page-standard.h>
 #include <libgnomeui/gnome-druid-page-edge.h>
@@ -42,6 +44,10 @@
 /**
  * Private data
  */
+#define GB_IMPORT_DRUID_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), \
+				       GB_TYPE_IMPORT_DRUID, GbImportDruidPrivate))
+
+
 struct _GbImportDruidPrivate {
 
 	GbBookmarkSet *dest;
@@ -69,8 +75,6 @@ struct _GbImportDruidPrivate {
 /**
  * Private functions, only availble from this file
  */
-static void		gb_import_druid_class_init		(GbImportDruidClass *klass);
-static void		gb_import_druid_init			(GbImportDruid *d);
 static void		gb_import_druid_init_widgets		(GbImportDruid *d);
 static void		gb_import_druid_init_location_widgets 	(GbImportDruid *d);
 static void		gb_import_druid_init_merge_widgets 	(GbImportDruid *d);
@@ -90,20 +94,15 @@ static void 		gb_import_druid_page_5_prepare_cb	(GnomeDruidPage *druid_page,
 static void		gb_import_druid_location_list_selection_changed_cb (GtkTreeSelection *ts, 
 									    GbImportDruid *d);
 static void		gb_import_druid_location_entry_changed_cb (GtkEditable *e, GbImportDruid *d);
-static gboolean		gb_import_druid_window_configure_event_cb (GtkWidget *widget,
-								   GdkEventConfigure *event,
-								   GbImportDruid *d);
 static void		gb_import_druid_merge_button_clicked_cb	(GtkButton *b, GbImportDruid *d);
 
 
-static gpointer g_object_class;
 
 /**
  * ImportDruid object
  */
 
-MAKE_GET_TYPE (gb_import_druid, "GbImportDruid", GbImportDruid, gb_import_druid_class_init, 
-	       gb_import_druid_init, G_TYPE_OBJECT);
+G_DEFINE_TYPE (GbImportDruid, gb_import_druid, G_TYPE_OBJECT);
 
 static void
 gb_import_druid_class_init (GbImportDruidClass *klass)
@@ -112,13 +111,14 @@ gb_import_druid_class_init (GbImportDruidClass *klass)
 	klass->get_locations = gb_import_druid_get_locations_impl;
 	klass->get_io = gb_import_druid_get_io_impl;
 	G_OBJECT_CLASS (klass)->finalize = gb_import_druid_finalize_impl;
-	g_object_class = g_type_class_peek_parent (klass);
+
+	g_type_class_add_private (klass, sizeof (GbImportDruidPrivate));
 }
 
 static void 
 gb_import_druid_init (GbImportDruid *e)
 {
-	GbImportDruidPrivate *p = g_new0 (GbImportDruidPrivate, 1);
+	GbImportDruidPrivate *p = GB_IMPORT_DRUID_GET_PRIVATE (e);
 	e->priv = p;
 	
 }
@@ -141,9 +141,8 @@ gb_import_druid_finalize_impl (GObject *o)
 
 	g_free (p->location);
 	g_free (p->backup_filename);
-	g_free (p);
 	
-	G_OBJECT_CLASS (g_object_class)->finalize (o);
+	G_OBJECT_CLASS (gb_import_druid_parent_class)->finalize (o);
 
 }
 
@@ -161,7 +160,7 @@ gb_import_druid_init_widgets (GbImportDruid *d)
 	gtk_window_set_title (GTK_WINDOW (p->window), 
 			      gb_import_druid_get_string (d, "window title"));
 
-	g_signal_connect_swapped (p->window, "delete_event", G_CALLBACK (g_object_unref), d);
+	g_object_weak_ref (G_OBJECT (p->window), (GWeakNotify) g_object_unref, d);
 
 	p->druid = GNOME_DRUID (gnome_druid_new ());
 	gtk_widget_show (GTK_WIDGET (p->druid));
@@ -207,7 +206,7 @@ gb_import_druid_init_widgets (GbImportDruid *d)
 					       _("Found possible locations:"),
 					       w,
 					       _("These locations are typical places where "
-						 "bookmarks can be found"));
+						 "bookmarks can be found."));
 
 	gnome_druid_page_standard_append_item (GNOME_DRUID_PAGE_STANDARD (page),
 					       _("Chosen location:"),
@@ -308,6 +307,14 @@ gb_import_druid_init_location_widgets (GbImportDruid *d)
 
 	p->location_entry = gnome_file_entry_new ("galeon-bookamrks-import-locations",
 						  _("Choose a file to import"));
+
+	/* Use the new file chooser if we can */
+	if (g_object_class_find_property (G_OBJECT_GET_CLASS (p->location_entry), 
+					  "use_filechooser" ))
+	{
+		g_object_set (p->location_entry, "use_filechooser", TRUE, NULL);
+	}
+
 	gtk_widget_show (p->location_entry);
 	g_signal_connect (gnome_entry_gtk_entry (GNOME_ENTRY (gnome_file_entry_gnome_entry 
 							      (GNOME_FILE_ENTRY (p->location_entry)))),
@@ -377,11 +384,6 @@ gb_import_druid_show (GbImportDruid *d)
 	g_return_if_fail (GB_IS_BOOKMARK_SET (p->dest));
 	g_return_if_fail (GTK_IS_WINDOW (p->window));
 	
-	/* window size saving crack */
-	gul_state_load_window (p->window, "bookmarks_import_druid", 600, 430, FALSE);
-	g_signal_connect (p->window, "configure_event", 
-			  G_CALLBACK (gb_import_druid_window_configure_event_cb), d);
-
 	gtk_widget_show (GTK_WIDGET (p->window));
 }
 
@@ -579,15 +581,6 @@ gb_import_druid_location_entry_changed_cb (GtkEditable *e, GbImportDruid *d)
 	p->location = sel;
 }
 
-static gboolean
-gb_import_druid_window_configure_event_cb (GtkWidget *widget,
-					   GdkEventConfigure *event,
-					   GbImportDruid *d)
-{
-	gul_state_save_window (widget, "bookmarks_import_druid");
-	return FALSE;
-}
-
 static void
 gb_import_druid_merge_button_clicked_cb (GtkButton *b, GbImportDruid *d)
 {
