@@ -21,9 +21,7 @@
 
 #include "AutoJSContextStack.h"
 
-#define MOZILLA_INTERNAL_API
-#include <nsIServiceManager.h>
-#undef MOZILLA_INTERNAL_API
+#include <nsServiceManagerUtils.h>
 
 AutoJSContextStack::~AutoJSContextStack()
 {
