@@ -159,9 +159,7 @@
 #include <nsIPromptService.h>
 #include <nsIWebProgressListener.h>
 #include <nsCOMPtr.h>
-#define MOZILLA_INTERNAL_API
-#include <nsIServiceManager.h>
-#undef MOZILLA_INTERNAL_API
+#include <nsServiceManagerUtils.h>
 #include <nsIInterfaceRequestorUtils.h>
 #include <nsIURI.h>
 #include <nsIURL.h>
@@ -219,11 +217,7 @@ struct MimeAskActionDialog
  * Mini progress listener so that we can listen for errors
  * while downloading */
 class MiniProgressListener
-#ifdef HAVE_NSIWEBPROGRESSLISTENER2_H
 	: public nsIWebProgressListener2
-#else
-	: public nsIWebProgressListener
-#endif
 {
 public:
 	MiniProgressListener(MimeAskActionDialog *dialog) : 
@@ -235,20 +229,13 @@ public:
 
  	NS_DECL_ISUPPORTS
 	NS_DECL_NSIWEBPROGRESSLISTENER
-#ifdef HAVE_NSIWEBPROGRESSLISTENER2_H
 	NS_DECL_NSIWEBPROGRESSLISTENER2
-#endif
-	
+
 	MimeAskActionDialog *mDialog;
 };
 
-#ifdef HAVE_NSIWEBPROGRESSLISTENER2_H
 NS_IMPL_ISUPPORTS2(MiniProgressListener, nsIWebProgressListener2,
 		   nsIWebProgressListener)
-#else
-NS_IMPL_ISUPPORTS1(MiniProgressListener,
-		   nsIWebProgressListener)
-#endif
 
 // ------------------------------------------------------------
 
@@ -274,11 +261,7 @@ GContentHandler::~GContentHandler()
 /* void show (in nsIHelperAppLauncher aLauncher, in nsISupports aContext); */
 NS_IMETHODIMP GContentHandler::Show(nsIHelperAppLauncher *aLauncher,
 				    nsISupports *aContext,
-#ifdef HAVE_NSIHELPERAPPLAUNCHERDIALOG_SHOW_REASON
 				    PRUint32 aReason)
-#else
-				    PRBool aForced)
-#endif
 {
 	/* aForced reflects if the content being sent is normally viewable
 	 * in mozilla or not. That fact doesn't affect us, so ignore it
@@ -300,6 +283,9 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 						   nsISupports *aWindowContext,
 						   const PRUnichar *aDefaultFile,
 						   const PRUnichar *aSuggestedFileExtension,
+#ifdef HAVE_NSIHELPERAPPLAUNCHERDIALOG_FORCEPROMPT
+						   PRBool aForcePrompt,
+#endif
 						   nsILocalFile **_retval)
 {
 	mContext = aWindowContext;
@@ -308,7 +294,11 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 	GtkWidget *parentWindow = GaleonUtils::FindGtkParent (parentDOMWindow);
 
 	/* Get the directory to use for downloading into */
+#ifdef HAVE_NSIHELPERAPPLAUNCHERDIALOG_FORCEPROMPT
+	if (!eel_gconf_get_boolean (CONF_DOWNLOADING_ASK_DIR) && !aForcePrompt)
+#else
 	if (!eel_gconf_get_boolean (CONF_DOWNLOADING_ASK_DIR))
+#endif
 	{
 		nsresult rv =  BuildDownloadPath (GulCString (aDefaultFile).get(),
 						  parentWindow, _retval);
@@ -416,11 +406,7 @@ NS_METHOD GContentHandler::LaunchHelperApp (void)
 
 	}
 
-#ifdef HAVE_NSICANCELABLE_H
 	mLauncher->Cancel (NS_BINDING_ABORTED);
-#else
-	mLauncher->Cancel ();
-#endif
 	return NS_OK;
 }
 
@@ -501,12 +487,7 @@ NS_METHOD GContentHandler::SynchroniseMIMEInfo (void)
 	char * info = g_strdup_printf ("%d:%s", gtk_get_current_event_time(),
 				       id);
 
-	rv = mimeInfo->SetApplicationDescription
-#ifdef HAVE_NSIMIMEINFO_NSASTRING
-		(GulString(info));
-#else
-		(GulString(info).get());
-#endif
+	rv = mimeInfo->SetDescription(GulString(info));
 	g_free (info);
 
 	if(NS_FAILED(rv)) return NS_ERROR_FAILURE;
@@ -526,15 +507,7 @@ NS_METHOD GContentHandler::Init (void)
 
 	nsCOMPtr<nsIMIMEInfo> MIMEInfo;
 	rv = mLauncher->GetMIMEInfo (getter_AddRefs(MIMEInfo));
-#ifdef HAVE_NSIMIMEINFO_NSASTRING
 	rv = MIMEInfo->GetMIMEType (mMimeType);
-#else
-	char *type = nsnull;
-	rv = MIMEInfo->GetMIMEType (&type);
-	mMimeType = type;
-	nsMemory::Free (type);
-#endif
-	
 	rv = mLauncher->GetSource(getter_AddRefs(mUri));
 	rv = mLauncher->GetTargetFile(getter_AddRefs(mTempFile));
 
@@ -554,16 +527,9 @@ NS_METHOD GContentHandler::ProcessMimeInfo (void)
 		// suggested filename
 		GulCString uriFileName;
 
-#ifdef HAVE_NSIMIMEINFO_NSASTRING
 		GulString filename;
 		mLauncher->GetSuggestedFileName (filename);
 		uriFileName = filename;
-#else
-		PRUnichar *filename = nsnull;
-		mLauncher->GetSuggestedFileName(&filename);
-		uriFileName = filename;
-		nsMemory::Free(filename);
-#endif
 
 #ifdef HAVE_GNOME_VFS_GET_MIME_TYPE_FOR_NAME
 		mMimeType.Assign(gnome_vfs_get_mime_type_for_name
@@ -590,11 +556,7 @@ NS_METHOD GContentHandler::MIMEAskAction (void)
 	 * errors while the download is happening to a temporary file
 	 * - bug 148739
 	 */
-#ifdef HAVE_NSIWEBPROGRESSLISTENER2_H
 	nsCOMPtr<nsIWebProgressListener2> listener = new MiniProgressListener( dialog );
-#else
-	nsCOMPtr<nsIWebProgressListener> listener = new MiniProgressListener( dialog );
-#endif
 	mLauncher->SetWebProgressListener( listener );
 
 	return NS_OK;
@@ -717,16 +679,9 @@ MimeAskActionDialog::MimeAskActionDialog(GContentHandler *aContentHandler,
 
 	// suggested filename
 	GulCString filename;
-#ifdef HAVE_NSIMIMEINFO_NSASTRING
 	GulString uFilename;
 	launcher->GetSuggestedFileName (uFilename);
 	filename = uFilename;
-#else
-	PRUnichar *uFilename = nsnull;
-	launcher->GetSuggestedFileName(&uFilename);
-	filename = uFilename;
-	nsMemory::Free(uFilename);
-#endif
 
 	markup = g_markup_printf_escaped("<b>%s</b>", filename.get());
 
@@ -792,11 +747,7 @@ mime_ask_dialog_save_clicked_cb(GtkButton *button, MimeAskActionDialog *dialog)
 	}
 	else
 	{
-#ifdef HAVE_NSICANCELABLE_H
 		launcher->Cancel(NS_BINDING_ABORTED);
-#else
-		launcher->Cancel();
-#endif
 		dialog->mContentHandler->LaunchExternalDownloader();
 	}
 	
@@ -810,11 +761,7 @@ mime_ask_dialog_download_cancel (MimeAskActionDialog *dialog)
 	dialog->mContentHandler->GetLauncher(getter_AddRefs(launcher));
 
 	launcher->SetWebProgressListener( nsnull );
-#ifdef HAVE_NSICANCELABLE_H
 	launcher->Cancel(NS_BINDING_ABORTED);
-#else
-	launcher->Cancel();
-#endif
 
 	delete dialog;
 }
@@ -888,11 +835,7 @@ mime_ask_dialog_close_cb(GtkWidget *dialogWidget, MimeAskActionDialog *dialog)
 	rv = dialog->mContentHandler->GetLauncher(getter_AddRefs(launcher));
 
 	launcher->SetWebProgressListener( nsnull );
-#ifdef HAVE_NSICANCELABLE_H
 	launcher->Cancel(NS_BINDING_ABORTED);
-#else
-	launcher->Cancel();
-#endif
 }
 
 // ------------------------------------------------------------
@@ -957,7 +900,6 @@ NS_IMETHODIMP MiniProgressListener::OnSecurityChange(nsIWebProgress *aWebProgres
 	return NS_ERROR_NOT_IMPLEMENTED;
 }
 
-#ifdef HAVE_NSIWEBPROGRESSLISTENER2_H
 NS_IMETHODIMP MiniProgressListener::OnProgressChange64(nsIWebProgress *aWebProgress,
 						nsIRequest *aRequest, PRInt64 aCurSelfProgress,
 						PRInt64 aMaxSelfProgress, PRInt64 aCurTotalProgress,
@@ -975,5 +917,3 @@ NS_IMETHODIMP MiniProgressListener::OnRefreshAttempted(nsIWebProgress *aWebProgr
 }
 #endif
 
-#endif
-
