@@ -19,10 +19,8 @@
 #include <config.h>
 #endif
 
-#define MOZILLA_INTERNAL_API
 #include <nscore.h>
-#include <nsIServiceManager.h>
-#undef MOZILLA_INTERNAL_API
+#include <nsComponentManagerUtils.h>
 
 #include "EventContext.h"
 #include "GaleonWrapper.h"
@@ -562,15 +560,6 @@ nsresult EventContext::GetMouseEventInfo (nsIDOMMouseEvent *aMouseEvent, GaleonE
 			info->mouse_button = btn+1;
 		break;
 
-#ifdef HAVE_BROKEN_CTX_MENU_EVENT
-		/* This only appears to happen when getting a mouse context menu
-		 * signal, so map it to button 3 (right mouse button)
-		 * - http://bugzilla.mozilla.org/show_bug.cgi?id=258193 */
-	        case 500: 
-			info->mouse_button = 3;
-		break;
-#endif
-
 		case (PRUint16) -1:
 			/* when the user submits a form with Return, mozilla synthesises
 			 * a _mouse_ click event with btn=65535 (-1).
@@ -916,14 +905,12 @@ EventContext::CheckKeyPress (nsIDOMKeyEvent *aEvent)
 {
 	PRBool retval = PR_FALSE;
 
-#ifdef HAVE_NSIDOMNSEVENT_GETISTRUSTED
 	/* make sure the event is trusted */
 	nsCOMPtr<nsIDOMNSEvent> nsEvent (do_QueryInterface (aEvent));
 	NS_ENSURE_TRUE (nsEvent, retval);
 	PRBool isTrusted = PR_FALSE;
 	nsEvent->GetIsTrusted (&isTrusted);
 	if (!isTrusted) return retval;
-#endif
 
 	/* check for alt/ctrl */
 	PRBool isCtrl = PR_FALSE, isAlt = PR_FALSE;
@@ -975,6 +962,9 @@ EventContext::CheckKeyPress (nsIDOMKeyEvent *aEvent)
 	rv = node->GetOwnerDocument (getter_AddRefs (doc));
 	NS_ENSURE_SUCCESS (rv, retval);
 
+	nsCOMPtr<nsIDOMXULDocument> xul_document (do_QueryInterface(doc, &rv));
+	if (xul_document) return retval;
+
 	nsCOMPtr<nsIDOMNSHTMLDocument> htmlDoc (do_QueryInterface (doc));
 	if (htmlDoc)
 	{
