@@ -27,18 +27,14 @@
 
 #include <nsCOMPtr.h>
 #include <nsCOMPtr.h>
-#define MOZILLA_INTERNAL_API
-#include <nsIServiceManager.h>
-#undef MOZILLA_INTERNAL_API
+#include <nsServiceManagerUtils.h>
+#include <nsComponentManagerUtils.h>
 #include <nsIURI.h>
 #include <nsIFileURL.h>
 #include <nsILocalFile.h>
 #include <nsIDOMWindow.h>
 #include <nsNetCID.h>
-
-#ifndef HAVE_NSIFILEPICKER_NSASTRING
-#include <nsIDOMWindowInternal.h>
-#endif
+#include <nsXPCOMCID.h>
 
 #include "gul-string.h"
 #include "prefs-strings.h"
@@ -70,11 +66,7 @@ GFilePicker::~GFilePicker()
 }
 
 /* void init (in nsIDOMWindowInternal parent, in wstring title, in short mode); */
-#ifdef HAVE_NSIFILEPICKER_NSASTRING
 NS_IMETHODIMP GFilePicker::Init(nsIDOMWindow *parent, const nsAString &title, PRInt16 mode)
-#else
-NS_IMETHODIMP GFilePicker::Init(nsIDOMWindowInternal *parent, const PRUnichar *title, PRInt16 mode)
-#endif
 {
 	LOG ("GFilePicker::Init");
 
@@ -161,11 +153,7 @@ NS_IMETHODIMP GFilePicker::AppendFilters(PRInt32 filterMask)
 }
 
 /* void appendFilter (in wstring title, in wstring filter); */
-#ifdef HAVE_NSIFILEPICKER_NSASTRING
 NS_IMETHODIMP GFilePicker::AppendFilter(const nsAString &title, const nsAString &filter)
-#else
-NS_IMETHODIMP GFilePicker::AppendFilter(const PRUnichar *title, const PRUnichar *filter)
-#endif
 {
         NS_ENSURE_TRUE (mDialog, NS_ERROR_FAILURE);
 
@@ -198,30 +186,18 @@ nsresult GFilePicker::AppendFilter (const char * title, const char * pattern)
 }
 
 /* attribute wstring defaultString; */
-#ifdef HAVE_NSIFILEPICKER_NSASTRING
 NS_IMETHODIMP GFilePicker::GetDefaultString(nsAString &aDefaultString)
-#else
-NS_IMETHODIMP GFilePicker::GetDefaultString(PRUnichar **aDefaultString)
-#endif
 {
         NS_ENSURE_TRUE (mDialog, NS_ERROR_FAILURE);
 
 	LOG ("GFilePicker::GetDefaultString");
 
-#ifdef HAVE_NSIFILEPICKER_NSASTRING
 	aDefaultString = mDefaultString;
-#else
-	*aDefaultString = NS_StringCloneData (mDefaultString);
-#endif
 
 	return NS_OK;
 }
 
-#ifdef HAVE_NSIFILEPICKER_NSASTRING
 NS_IMETHODIMP GFilePicker::SetDefaultString(const nsAString &aDefaultString)
-#else
-NS_IMETHODIMP GFilePicker::SetDefaultString(const PRUnichar *aDefaultString)
-#endif
 {
         NS_ENSURE_TRUE (mDialog, NS_ERROR_FAILURE);
 
@@ -245,22 +221,14 @@ NS_IMETHODIMP GFilePicker::SetDefaultString(const PRUnichar *aDefaultString)
 }
 
 /* attribute wstring defaultExtension; */
-#ifdef HAVE_NSIFILEPICKER_NSASTRING
 NS_IMETHODIMP GFilePicker::GetDefaultExtension(nsAString &aDefaultExtension)
-#else
-NS_IMETHODIMP GFilePicker::GetDefaultExtension(PRUnichar **aDefaultExtension)
-#endif
 {
 	LOG ("GFilePicker::GetDefaultExtension");
 
 	return NS_ERROR_NOT_IMPLEMENTED;
 }
 
-#ifdef HAVE_NSIFILEPICKER_NSASTRING
 NS_IMETHODIMP GFilePicker::SetDefaultExtension(const nsAString &aDefaultExtension)
-#else
-NS_IMETHODIMP GFilePicker::SetDefaultExtension(const PRUnichar *aDefaultExtension)
-#endif
 {
 	LOG ("GFilePicker::SetDefaultExtension()");
 
@@ -354,8 +322,12 @@ NS_IMETHODIMP GFilePicker::GetFile(nsILocalFile **aFile)
 	return NS_OK;
 }
 
-/* readonly attribute nsIFileURL fileURL; */
+/* readonly attribute nsIURI/nsIFileURL fileURL; */
+#ifdef HAVE_NSIFILEPICKER_NSIURI
+NS_IMETHODIMP GFilePicker::GetFileURL(nsIURI **aFileURL)
+#else
 NS_IMETHODIMP GFilePicker::GetFileURL(nsIFileURL **aFileURL)
+#endif
 {
 	LOG ("GFilePicker::GetFileURL");
 
