@@ -21,9 +21,7 @@
 #endif
 
 #include <nscore.h>
-#define MOZILLA_INTERNAL_API
-#include <nsIServiceManager.h>
-#undef MOZILLA_INTERNAL_API
+#include <nsServiceManagerUtils.h>
 
 #include "galeon-embed.h"
 #include "galeon-debug.h"
@@ -206,28 +204,11 @@ nsresult GaleonWrapper::Init (GtkMozEmbed *mozembed)
 
 
 #ifdef HAVE_MOZILLA_PSM
-#ifdef HAVE_NSIDOCSHELL_GETSECUREUI
 	nsCOMPtr<nsIDocShell> docShell (do_GetInterface (mWebBrowser, &rv));
 	NS_ENSURE_SUCCESS (rv, rv);
 
 	rv = docShell->GetSecurityUI (getter_AddRefs (mSecurityInfo));
 	NS_ENSURE_SUCCESS (rv, rv);
-#else
-	/* FIXME: mozilla sucks! nsWebBrowser already has an instance of this,
-	 * but we cannot get to it!
-	 * See https://bugzilla.mozilla.org/show_bug.cgi?id=94974,
-	 * also see http://bugzilla.gnome.org/show_bug.cgi?id=164670
-	 */
-	mSecurityInfo = do_CreateInstance("@galeon.sf.net/hacks/secure-browser-ui;1");
-	if (mSecurityInfo)
-	{
-		mSecurityInfo->Init (DOMWindow);
-	}
-	else
-	{
-		g_warning ("Failed to instantiate nsISecureBrowserUI!\n");
-	}
-#endif
 #endif
 
 	return NS_OK;
@@ -1209,14 +1190,9 @@ nsresult GaleonWrapper::GetCacheEntryDescriptor(const nsAString &aKey,
 		
 		nsCOMPtr<nsICacheEntryDescriptor> cacheEntryDescriptor;
 
-#ifdef HAVE_NSICACHESESSION_NSACSTRING
 		rv = cacheSession->OpenCacheEntry(GulDependentCString(url),
 						  nsICache::ACCESS_READ,
 						  PR_FALSE,  aCacheEntryDescriptor);
-#else
-		rv = cacheSession->OpenCacheEntry(url, nsICache::ACCESS_READ,
-						  PR_FALSE,  aCacheEntryDescriptor);
-#endif
 		if (NS_SUCCEEDED (rv)) break;
 	}
 	g_free (url);
@@ -1240,7 +1216,7 @@ nsresult GaleonWrapper::GetPageProperties (EmbedPageProperties *props)
 	doc->GetLastModified(value);
 	nsTime last_modified (GulCString(value).get(), PR_TRUE);
 	LL_DIV (props->modification_time,
-		NS_STATIC_CAST(PRTime, last_modified), PR_USEC_PER_SEC);
+		static_cast<PRTime>(last_modified), PR_USEC_PER_SEC);
 
 	doc->GetContentType(value);
 	props->content_type = g_strdup (GulCString(value).get());
@@ -1645,19 +1621,23 @@ public:
     ~GConsoleMessage() {}
 
     NS_DECL_ISUPPORTS
-
-    NS_IMETHODIMP GetMessage(PRUnichar **result)
-    {
-	    *result = NS_StringCloneData (mMessage);
-	    return NS_OK;
-    }
+    NS_DECL_NSICONSOLEMESSAGE
 
 private:
     GulString mMessage;
 };
 
-NS_IMPL_THREADSAFE_ISUPPORTS1(GConsoleMessage, nsIConsoleMessage)
+#ifdef HAVE_NSICONSOLEMESSAGE_GETMESSAGEMOZ
+NS_IMETHODIMP GConsoleMessage::GetMessageMoz(PRUnichar **result)
+#else
+NS_IMETHODIMP GConsoleMessage::GetMessage(PRUnichar **result)
+#endif
+{
+	*result = NS_StringCloneData (mMessage);
+	return NS_OK;
+}
 
+NS_IMPL_ISUPPORTS1(GConsoleMessage, nsIConsoleMessage)
 
 nsresult GaleonWrapper::EvaluateJS (const char *script)
 {
@@ -1989,7 +1969,6 @@ GDOMEventListener::HandleEvent (nsIDOMEvent* aDOMEvent)
 		/* refuse if we can't check */
 		NS_ENSURE_TRUE (policy, NS_ERROR_FAILURE);
 
-#ifdef HAVE_NEW_NSICONTENTPOLICY_API
 		GulString typeVal;
 		elem->GetAttribute (NS_LITERAL_STRING ("type"), typeVal);
 
@@ -2001,15 +1980,6 @@ GDOMEventListener::HandleEvent (nsIDOMEvent* aDOMEvent)
 					 &decision);
 		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 		if (decision != nsIContentPolicy::ACCEPT) return NS_OK;
-#else
-		PRBool shouldLoad = PR_FALSE;
-		rv = policy->ShouldLoad (nsIContentPolicy::IMAGE,
-					 favUri, target,
-					 domWin,
-					 &shouldLoad);
-		NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
-		if (!shouldLoad) return NS_OK;
-#endif
 
 		/* ok, we accept this as a valid favicon for this site */
 		g_signal_emit_by_name (mEmbed, "ge_favicon", favicon.get());
@@ -2066,7 +2036,6 @@ GDOMPopupEventListener::HandleEvent (nsIDOMEvent* aDOMEvent)
 NS_IMETHODIMP
 GDOMModalAlertEventListener::HandleEvent (nsIDOMEvent * aDOMEvent)
 {
-#ifdef HAVE_NSIDOMNSEVENT_GETISTRUSTED
 	NS_ENSURE_TRUE (mEmbed, NS_ERROR_FAILURE);
 
 	/* make sure the event is trusted */
@@ -2101,7 +2070,6 @@ GDOMModalAlertEventListener::HandleEvent (nsIDOMEvent * aDOMEvent)
 		g_signal_emit_by_name (mEmbed, "ge-modal-alert-closed");
 	}
 
-#endif
 	return NS_OK;
 }
 
