@@ -35,9 +35,7 @@
 
 #include <nsCOMPtr.h>
 #include <nsMemory.h>
-#define MOZILLA_INTERNAL_API
-#include <nsIServiceManager.h>
-#undef MOZILLA_INTERNAL_API
+#include <nsServiceManagerUtils.h>
 #include <nsIInterfaceRequestor.h>
 #include <nsIInterfaceRequestorUtils.h>
 #include <nsIX509Cert.h>
@@ -102,9 +100,14 @@ GtkNSSDialogs::~GtkNSSDialogs ()
 {
 }
 
+#ifdef HAVE_NSIBADCERTLISTENER_H
 NS_IMPL_ISUPPORTS2 (GtkNSSDialogs, 
 		    nsICertificateDialogs,
 		    nsIBadCertListener)
+#else
+NS_IMPL_ISUPPORTS1 (GtkNSSDialogs, 
+		    nsICertificateDialogs)
+#endif
 
 /**
  *  Call the mozilla service to display a certificate
@@ -288,6 +291,7 @@ display_cert_warning_box (nsIInterfaceRequestor *ctx,
 }
 
 
+#ifdef HAVE_NSIBADCERTLISTENER_H
 NS_IMETHODIMP
 GtkNSSDialogs::ConfirmMismatchDomain (nsIInterfaceRequestor *ctx,
                                       const nsACString &targetURL,
@@ -539,6 +543,7 @@ GtkNSSDialogs::NotifyCrlNextupdate (nsIInterfaceRequestor *ctx,
 	gtk_widget_show_all (dialog);
 	return NS_OK;
 }
+#endif
 
 NS_IMETHODIMP 
 GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx, 
