@@ -55,9 +55,8 @@
 #include "prefs-strings.h"
 #include "hig-alert.h"
 
-#define MOZILLA_INTERNAL_API
-#include <nsIServiceManager.h>
-#undef MOZILLA_INTERNAL_API
+#include <nsComponentManagerUtils.h>
+#include <nsServiceManagerUtils.h>
 #include <nsIChannel.h>
 #include <nsIHttpChannel.h>
 #include <nsIEncodedChannel.h>
@@ -67,7 +66,6 @@
 #include <nsIMIMEService.h>
 #include <nsIMIMEInfo.h>
 #include <nsIDOMHTMLDocument.h>
-#include <nsIDownload.h>
 #include <nsIWindowWatcher.h>
 #include <nsNetCID.h>
 #include <nsIDOMDocument.h>
@@ -216,17 +214,7 @@ HeaderSniffer::OnStopRequest (nsIRequest *aRequest,
 	{
 		nsCOMPtr<nsIMIMEService> mimeService (do_GetService(NS_MIMESERVICE_CONTRACTID));
 
-#ifdef HAVE_NSIMIMEINFO_NSASTRING
 		mimeService->GetTypeFromURI (mFinalURL, contentType);
-#else
-		char *type = nsnull;
-		rv = mimeService->GetTypeFromURI (mFinalURL, &type);
-		if (NS_SUCCEEDED (rv))
-		{
-			contentType = type;
-			nsMemory::Free (type);
-		}
-#endif
 	}
 
 	/* Calculate whether we whould decode */
@@ -243,15 +231,9 @@ HeaderSniffer::OnStopRequest (nsIRequest *aRequest,
 			GulCString extension;
 			resultURL->GetFileExtension (extension);
 
-#ifdef HAVE_NSIMIMEINFO_NSASTRING
 			rv = helperService->ApplyDecodingForExtension (extension,
 								       contentEncoding,
 								       &mShouldDecode);
-#else
-			rv = helperService->ApplyDecodingForExtension (extension.get(),
-								       contentEncoding.get(),
-								       &mShouldDecode);
-#endif
 
 			if (NS_FAILED (rv))
 			{
@@ -325,21 +307,12 @@ HeaderSniffer::GetDefaultExtension (const GulCString &aFilename,
 	nsCOMPtr<nsIMIMEService> mimeService (do_GetService(NS_MIMESERVICE_CONTRACTID));
 
 	nsCOMPtr<nsIMIMEInfo> mimeInfo;
-#ifdef HAVE_NSIMIMEINFO_NSASTRING
 	mimeService->GetFromTypeAndExtension (aContentType, extension, 
 					      getter_AddRefs (mimeInfo));
-#else
-	mimeService->GetFromTypeAndExtension (aContentType.get(), extension.get(), 
-					      getter_AddRefs (mimeInfo));
-#endif
 	if (extension.Length() && mimeInfo)
 	{
 		PRBool exists = PR_FALSE;
-#ifdef HAVE_NSIMIMEINFO_NSASTRING
 		mimeInfo->ExtensionExists (extension, &exists);
-#else
-		mimeInfo->ExtensionExists (extension.get(), &exists);
-#endif
 		if (exists)
 		{
 			_retval = extension;
@@ -358,11 +331,7 @@ HeaderSniffer::GetDefaultExtension (const GulCString &aFilename,
 	if (urlExtension.Length() && mimeInfo)
 	{
 		PRBool exists = PR_FALSE;
-#ifdef HAVE_NSIMIMEINFO_NSASTRING
 		mimeInfo->ExtensionExists (urlExtension, &exists);
-#else
-		mimeInfo->ExtensionExists (urlExtension.get(), &exists);
-#endif
 		if (exists)
 		{
 			_retval = urlExtension;
@@ -374,22 +343,11 @@ HeaderSniffer::GetDefaultExtension (const GulCString &aFilename,
 	 * primary extension if the mime type has one */
 	if( mimeInfo )
 	{
-#ifdef HAVE_NSIMIMEINFO_NSASTRING
 		rv = mimeInfo->GetPrimaryExtension (_retval);
 		if (NS_SUCCEEDED (rv))
 		{
 			return NS_OK;
 		}
-#else
-		char *ext = nsnull;
-		rv = mimeInfo->GetPrimaryExtension (&ext);
-		if (NS_SUCCEEDED (rv))
-		{
-			_retval = ext;
-			nsMemory::Free (ext);
-			return NS_OK;
-		}
-#endif
 	}
 
 	_retval = extension.Length() ? extension : urlExtension;
