@@ -42,9 +42,7 @@
 #endif
 
 #include "ExternalProtocolService.h"
-#include "gUrlCID.h"
 #include "GaleonAboutModule.h"
-#include "nsMailtoUrl.h"
 
 #ifdef HAVE_NSICLASSINFOIMPL_H
 #include <nsIClassInfoImpl.h>
@@ -52,11 +50,13 @@
 #include <nsIGenericFactory.h>
 #include <nsIComponentRegistrar.h>
 #include <nsICategoryManager.h>
+#include <nsIComponentManager.h>
 #include <nsCOMPtr.h>
-#define MOZILLA_INTERNAL_API
-#include <nsIServiceManager.h>
-#undef MOZILLA_INTERNAL_API
+#include <nsXPCOM.h>
+#include <nsComponentManagerUtils.h>
+#include <nsServiceManagerUtils.h>
 #include <nsDocShellCID.h>
+#include <nsXPCOMCID.h>
 
 #include <glib.h>
 
@@ -68,7 +68,6 @@ NS_GENERIC_FACTORY_CONSTRUCTOR(GPrintingPromptService)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GSidebarProxy)
 NS_DECL_CLASSINFO(GSidebarProxy)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GCookiePromptService)
-NS_GENERIC_FACTORY_CONSTRUCTOR(GaleonAboutModule)
 NS_GENERIC_FACTORY_CONSTRUCTOR(EphyPromptService)
 #ifdef HAVE_MOZILLA_PSM
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSDialogs)
@@ -76,13 +75,16 @@ NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSKeyPairDialogs)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSClientAuthDialogs)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSSecurityWarningDialogs)
 #endif
+#ifdef HAVE_NSSTRING_INTERNAL
+NS_GENERIC_FACTORY_CONSTRUCTOR(GaleonAboutModule)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GMyportalProtocolHandler)
+#endif
+#ifndef XPCOM_GLUE
 NS_GENERIC_FACTORY_CONSTRUCTOR(GExternalProtocolService)
+#endif
 #ifdef HAVE_NSIJSCONSOLESERVICE_H
 NS_GENERIC_FACTORY_CONSTRUCTOR(JSConsoleService)
 #endif
-NS_GENERIC_FACTORY_CONSTRUCTOR(nsMailtoUrl);
-static NS_DEFINE_CID(kMailtoUrlCID, NS_MAILTOURL_CID);
 
 // NS_DOWNLOAD_CONTRACTID was renamed in mozilla 1.8b
 #ifndef NS_TRANSFER_CONTRACTID
@@ -136,12 +138,14 @@ static const nsModuleComponentInfo sAppComps[] = {
 		NS_IHELPERAPPLAUNCHERDLG_CONTRACTID,
 		GContentHandlerConstructor
 	},
+#ifndef XPCOM_GLUE
 	{
 		G_EXTERNALPROTOCOLSERVICE_CLASSNAME,
 		G_EXTERNALPROTOCOLSERVICE_CID,
 		NS_EXTERNALPROTOCOLSERVICE_CONTRACTID,
 		GExternalProtocolServiceConstructor
 	},
+#endif
 	{
 		GALEON_GLOBALHISTORY_CLASSNAME,
 		GALEON_GLOBALHISTORY_CID,
@@ -174,12 +178,14 @@ static const nsModuleComponentInfo sAppComps[] = {
 		GCookiePromptServiceConstructor
 	},
 #ifdef HAVE_MOZILLA_PSM
+#ifdef HAVE_NSIBADCERTLISTENER_H
 	{
 		GTK_NSSDIALOGS_CLASSNAME,
 		GTK_NSSDIALOGS_CID,
 		NS_BADCERTLISTENER_CONTRACTID,
 		GtkNSSDialogsConstructor
 	},
+#endif
 	{
 		GTK_NSSDIALOGS_CLASSNAME,
 		GTK_NSSDIALOGS_CID,
@@ -205,6 +211,7 @@ static const nsModuleComponentInfo sAppComps[] = {
                 GtkNSSSecurityWarningDialogsConstructor
         },
 #endif
+#ifdef HAVE_NSSTRING_INTERNAL
 	{
 		G_ABOUT_MYPORTAL_CLASSNAME,
 		G_MYPORTAL_PROTOCOL_CID,
@@ -229,6 +236,7 @@ static const nsModuleComponentInfo sAppComps[] = {
 		GALEON_ABOUT_NETERROR_CONTRACTID,
 		GaleonAboutModuleConstructor
 	},
+#endif
 	{
 		EPHY_PROMPT_SERVICE_CLASSNAME,
 		EPHY_PROMPT_SERVICE_IID,
@@ -243,12 +251,6 @@ static const nsModuleComponentInfo sAppComps[] = {
 		EphyPromptServiceConstructor
 	},
 #endif /* HAVE_NSINONBLOCKINGALERTSERVICE_H */
-	{
-		NS_MAILTOURL_CLASSNAME,
-		NS_MAILTOURL_CID,
-		NS_MAILTOURL_CONTRACTID,
-		nsMailtoUrlConstructor
-	}
 };
 
 #define NS_MSGCONTENTPOLICY_CONTRACTID "@mozilla.org/messenger/content-policy;1"
@@ -266,41 +268,6 @@ remove_thunderbird_contentpolicy()
 	return NS_OK;
 }
 
-#if defined(HAVE_MOZILLA_PSM) && ! defined(HAVE_NSIDOCSHELL_GETSECUREUI)
-/* feb0fe98-f5ee-4d26-ad76-70856de63720 */
-#define NEW_CID { 0xfeb0fe98, 0xf5ee, 0x4d26, { 0xad, 0x76, 0x70, 0x85, 0x6d, 0xe6, 0x37, 0x20 } }
-
-static nsresult
-reregister_secure_browser_ui (nsIComponentManager *cm, nsIComponentRegistrar *cr)
-{
-	nsresult rv;
-	
-	/* Workaround as a result of:
-	 *  https://bugzilla.mozilla.org/show_bug.cgi?id=94974
-	 * see
-	 *  http://bugzilla.gnome.org/show_bug.cgi?id=164670
-	 */
-	nsCOMPtr<nsIFactory> factory;
-	rv = cm->GetClassObjectByContractID ("@mozilla.org/secure_browser_ui;1", 
-					     NS_GET_IID(nsIFactory), getter_AddRefs (factory));
-	NS_ENSURE_SUCCESS (rv, rv);
-
-	nsCID *cidPtr = nsnull;
-	rv = cr->ContractIDToCID("@mozilla.org/secure_browser_ui;1", &cidPtr);
-	NS_ENSURE_SUCCESS (rv, rv);
-
-	rv = cr->UnregisterFactory (*cidPtr, factory);
-	NS_ENSURE_SUCCESS (rv, rv);
-
-	const nsCID new_cid = NEW_CID;
-	rv = cr->RegisterFactory (new_cid, "Galeon Secure Browser Class",
-				  "@galeon.sf.net/hacks/secure-browser-ui;1", factory);
-	NS_ENSURE_SUCCESS (rv, rv);
-
-	return NS_OK;
-}
-#endif
-
 gboolean
 mozilla_register_components (void)
 {
@@ -315,23 +282,18 @@ mozilla_register_components (void)
 	NS_GetComponentManager (getter_AddRefs (cm));
 	NS_ENSURE_TRUE (cm, FALSE);
 
-	guint numAppComps = G_N_ELEMENTS (sAppComps);
-
-	/* See if we should register the nsMailtoUrl handler */
-	PRBool isMailtoUrlReg;
-	rv = cr->IsContractIDRegistered(NS_MAILTOURL_CONTRACTID,
-					&isMailtoUrlReg);
-	if (NS_SUCCEEDED(rv) && isMailtoUrlReg)
-	{
-		numAppComps--; /* No */
-	}
-
 	for (guint i = 0; i < G_N_ELEMENTS (sAppComps); i++)
 	{
 		nsCOMPtr<nsIGenericFactory> componentFactory;
-		rv = NS_NewGenericFactory(getter_AddRefs(componentFactory),
-					  &(sAppComps[i]));
-		if (NS_FAILED(rv) || !componentFactory)
+		componentFactory = do_CreateInstance(NS_GENERICFACTORY_CONTRACTID);
+		if(!componentFactory)
+		{
+			g_warning ("Failed to create a generic factory for %s\n", sAppComps[i].mDescription);
+			ret = FALSE;
+			continue;
+		}
+		rv = componentFactory->SetComponentInfo(&(sAppComps[i]));
+		if (NS_FAILED(rv))
 		{
 			g_warning ("Failed to make a factory for %s\n", sAppComps[i].mDescription);
 
@@ -365,10 +327,5 @@ mozilla_register_components (void)
 	// Thunderbird includes a fascist content policy - we don't need it
 	remove_thunderbird_contentpolicy ();
 
-#if defined(HAVE_MOZILLA_PSM) && ! defined(HAVE_NSIDOCSHELL_GETSECUREUI)
-	// Workaround for http://bugzilla.gnome.org/show_bug.cgi?id=164670
-	reregister_secure_browser_ui (cm, cr);
-#endif
-
 	return ret;
 }
