@@ -21,9 +21,13 @@
 #endif
 
 #include <nscore.h>
-#define MOZILLA_INTERNAL_API
-#include <nsIServiceManager.h>
-#undef MOZILLA_INTERNAL_API
+#include <nsComponentManagerUtils.h>
+#include <nsServiceManagerUtils.h>
+
+#ifdef XPCOM_GLUE
+#include <nsXPCOMGlue.h>
+#include <gtkmozembed_glue.cpp>
+#endif
 
 #define MOZILLA_CLIENT
 #include "gtkmozembed.h"
@@ -64,8 +68,10 @@
 #include <nsIPermissionManager.h>
 #include <nsICookieManager.h>
 #include <nsIPermission.h>
+#ifdef HAVE_NSIPASSWORD_H
 #include <nsIPasswordManager.h>
 #include <nsIPassword.h>
+#endif
 #include <nsICookie.h>
 #include <nsCPasswordManager.h>
 #include <nsIObserverService.h>
@@ -76,10 +82,7 @@
 
 //For setting the locale. hopefully gtkmozembed will do itself soon
 #include <nsIChromeRegistry.h>
-#include <locale/nsILocaleService.h>
-#ifdef HAVE_NSICHROMEREGISTRYSEA_H
-# include <chrome/nsIChromeRegistrySea.h>
-#endif
+#include <nsILocaleService.h>
 
 #ifdef HAVE_NSITOOLKITCHROMEREGISTRY_H
 #include "EphyDirectoryProvider.h"
@@ -157,8 +160,8 @@ mozilla_set_default_prefs (void)
 
 	// Also set vendor and vendorSub prefs so that mozilla can construct
 	// the user agent string for us.
-	pref->SetCharPref ("general.useragent.vendor", "Galeon");
-	pref->SetCharPref ("general.useragent.vendorSub", VERSION);
+	pref->SetCharPref ("general.useragent.vendor", USERAGENT_VENDOR);
+	pref->SetCharPref ("general.useragent.vendorSub", USERAGENT_VENDORSUB);
 
 	return TRUE;
 }
@@ -181,6 +184,7 @@ mozilla_init_single (MozillaEmbedShell *mes)
 			  mes);
 }
 
+#ifdef GALEON_MOZILLA_HOME
 static void
 mozilla_init_home (void)
 {
@@ -198,6 +202,7 @@ mozilla_init_home (void)
 #endif
 	g_free (mozilla_home);
 }
+#endif /* GALEON_MOZILLA_HOME */
 
 static void
 mozilla_init_profile (void)
@@ -230,8 +235,10 @@ mozilla_init_plugin_path ()
 	/* Add /usr/lib/mozilla/plugins (bug 149812) */
 	g_string_append (new_path, ":/usr/lib/mozilla/plugins");
 
+#ifdef GALEON_MOZILLA_HOME
 	/* Add the current mozilla build's plugins dir */
 	g_string_append (new_path, ":" GALEON_MOZILLA_HOME "/plugins");
+#endif
 
 	g_setenv ("MOZ_PLUGIN_PATH", new_path->str, TRUE);
 
@@ -299,68 +306,6 @@ mozilla_init_cookie_observer(void)
 	return TRUE;
 }
 
-#if HAVE_NSICHROMEREGISTRYSEA_H || HAVE_NSIXULCHROMEREGISTRY_SELECTLOCALE
-static nsresult
-getUILang(nsAString& aUILang)
-{
-	nsresult       result;
-	// get a locale service
-	nsCOMPtr<nsILocaleService> localeService = do_GetService(NS_LOCALESERVICE_CONTRACTID, &result);
-
-	if (NS_FAILED (result) || !localeService)
-	{
-		g_warning ("Could not get locale service!\n");
-		return NS_ERROR_FAILURE;
-	}
-        
-	result = localeService->GetLocaleComponentForUserAgent (aUILang);
-	if (NS_FAILED (result))
-	{
-		g_warning ("Could not determine locale!\n");
-		return result;
-	}
-
-	return NS_OK;
-}
- 
-// update global locale if possible (in case when user-*.rdf can be updated)
-// so that any apps after this can be invoked in the UILocale and contentLocale
-static gboolean
-mozilla_init_chrome (void)
-{
-	nsresult rv = NS_OK;
-	GulString uiLang;
-	// compute lang code
-	rv = getUILang(uiLang);
-	if (NS_FAILED (rv)) return FALSE;
-
-#ifdef HAVE_NSICHROMEREGISTRYSEA_H
-	nsCOMPtr<nsIChromeRegistrySea> chromeRegistry = do_GetService(NS_CHROMEREGISTRY_CONTRACTID, &rv);
-#else
-
-	nsCOMPtr<nsIXULChromeRegistry> chromeRegistry = do_GetService(NS_CHROMEREGISTRY_CONTRACTID, &rv);
-#endif
-	if (NS_FAILED (rv) || !chromeRegistry)
-	{
-		g_warning ("Could not get the chrome registry!\n");
-		return FALSE;
-	}
-	
-	// set locale
-	chromeRegistry->SetRuntimeProvider(PR_TRUE);
-
-	// Dont worry if this fails, it is probably because the lang pack
-	// isn't installed.
-	chromeRegistry->SelectLocale (GulCString (uiLang), PR_FALSE);
-
-	// Make sure skin is classic so we get native scrollbars
-	rv = chromeRegistry->SelectSkin (NS_LITERAL_CSTRING("classic/1.0"), PR_FALSE);
-	if (NS_FAILED (rv)) return FALSE;
-
-	return TRUE;
-}
-#endif
-
 static void
 mozilla_embed_shell_init (MozillaEmbedShell *mes)
 {
@@ -368,19 +313,65 @@ mozilla_embed_shell_init (MozillaEmbedShell *mes)
 
 	mes->priv->encodings = NULL;
 
+	nsresult rv;
+#ifdef XPCOM_GLUE
+	static const GREVersionRange greVersion = {
+	  "1.9a", PR_TRUE,
+	  "1.9.*", PR_TRUE
+	};
+	char xpcomLocation[4096];
+	rv = GRE_GetGREPathWithProperties(&greVersion, 1, nsnull, 0, xpcomLocation, 4096);
+	if (NS_FAILED (rv))
+	{
+	  g_warning ("Could not determine locale!\n");
+	  return;
+	}
+
+	// Startup the XPCOM Glue that links us up with XPCOM.
+	rv = XPCOMGlueStartup(xpcomLocation);
+	if (NS_FAILED (rv))
+	{
+	  g_warning ("Could not determine locale!\n");
+	  return;
+	}
+
+	rv = GTKEmbedGlueStartup();
+	if (NS_FAILED (rv))
+	{
+	  g_warning ("Could not startup glue!\n");
+	  return;
+	}
+
+	rv = GTKEmbedGlueStartupInternal();
+	if (NS_FAILED (rv))
+	{
+	  g_warning ("Could not startup internal glue!\n");
+	  return;
+	}
+
+	char *lastSlash = strrchr(xpcomLocation, '/');
+	if (lastSlash)
+	  *lastSlash = '\0';
+
+	gtk_moz_embed_set_path(xpcomLocation);
+#endif // XPCOM_GLUE
+#ifdef GALEON_MOZILLA_HOME
+	mozilla_init_home ();
+#endif
 	/* Pre initialization */
 	mozilla_init_plugin_path();
-	mozilla_init_home ();
 	mozilla_init_profile ();
 
+	/* Fire up the beast */
+	gtk_moz_embed_push_startup ();
+
+
 #if HAVE_NSITOOLKITCHROMEREGISTRY_H
 	nsCOMPtr<nsIDirectoryServiceProvider> dp = new EphyDirectoryProvider ();
 	if (dp) {
 		gtk_moz_embed_set_directory_service_provider (dp);
 	}
 #endif
-	/* Fire up the best */
-	gtk_moz_embed_push_startup ();
 }
 
 
@@ -390,12 +381,6 @@ impl_initialize (GaleonEmbedShell *ges)
 	gboolean ret;
 	MozillaEmbedShell *mes = MOZILLA_EMBED_SHELL(ges);
 
-	/* Until gtkmozembed does this itself */
-#if HAVE_NSICHROMEREGISTRYSEA_H || HAVE_NSIXULCHROMEREGISTRY_SELECTLOCALE
-	ret = mozilla_init_chrome();
-	if (ret == FALSE) return FALSE;
-#endif
-
 	/* Post initialization */
 	ret = mozilla_set_default_prefs ();
 	if (ret == FALSE) return FALSE;
@@ -756,6 +741,7 @@ static GList *
 impl_list_passwords (GaleonEmbedShell *shell,
 		     PasswordType type)
 {
+#ifdef HAVE_NSIPASSWORD_H
         nsresult result = NS_ERROR_FAILURE;
 
         nsCOMPtr<nsIPasswordManager> passwordManager =
@@ -796,8 +782,10 @@ impl_list_passwords (GaleonEmbedShell *shell,
 
 		passwords = g_list_prepend (passwords, p);
         }       
-
 	return g_list_reverse (passwords);
+#else
+	return NULL;
+#endif
 }
 
 static void
