@@ -21,9 +21,7 @@
 #endif
 
 #include <nscore.h>
-#define MOZILLA_INTERNAL_API
-#include <nsIServiceManager.h>
-#undef MOZILLA_INTERNAL_API
+#include <nsServiceManagerUtils.h>
 
 #define MOZILLA_CLIENT
 #include "gtkmozembed.h"
@@ -1810,7 +1808,7 @@ impl_remove_user_stylesheet(GaleonEmbed *embed,
 {
 	if (!sheet) return;
 
-	MozillaEmbedStyleSheet *mess = NS_STATIC_CAST(MozillaEmbedStyleSheet*, sheet);
+	MozillaEmbedStyleSheet *mess = static_cast<MozillaEmbedStyleSheet*>(sheet);
 	g_return_if_fail(mess != NULL);
 
         GaleonWrapper *wrapper = MOZILLA_EMBED(embed)->priv->wrapper;
@@ -1830,7 +1828,7 @@ galeon_embed_stylesheet_new (EmbedStyleSheetType type, const char *name)
 void
 galeon_embed_stylesheet_free (EmbedStyleSheet *sheet)
 {
-	MozillaEmbedStyleSheet *mess = NS_STATIC_CAST(MozillaEmbedStyleSheet*, sheet);
+	MozillaEmbedStyleSheet *mess = static_cast<MozillaEmbedStyleSheet*>(sheet);
 
 	if (mess)
 	{
