@@ -155,7 +155,6 @@ tab_content_changed_cb (GaleonEmbed *embed,
 	set_controls (toolbar, TRUE, TRUE);
 }
 
-#ifdef HAVE_TYPEAHEADFIND
 
 /* Code adapted from gtktreeview.c:gtk_tree_view_key_press() and
  * gtk_tree_view_real_start_interactive_seach()
@@ -218,8 +217,6 @@ tab_search_key_press_cb (GaleonEmbed *embed,
 	return FALSE;
 }
 
-#endif /* HAVE_TYPEAHEADFIND */
-
 static void
 find_next_cb (GaleonFindToolbar *toolbar)
 {
@@ -239,9 +236,7 @@ entry_changed_cb (GtkEntry *entry,
 	GaleonFindToolbarPrivate *priv = toolbar->priv;
 	const char *text;
 	char *lowercase;
-#ifdef HAVE_TYPEAHEADFIND
 	GaleonEmbedFindResult result;
-#endif
 	gboolean found = TRUE, case_sensitive;
 
 	text = gtk_entry_get_text (GTK_ENTRY (priv->entry));
@@ -254,12 +249,10 @@ entry_changed_cb (GtkEntry *entry,
 	g_free (lowercase);
 
 	galeon_embed_find_set_properties (get_find (toolbar), text, case_sensitive);
-#ifdef HAVE_TYPEAHEADFIND
 	result = galeon_embed_find_find (get_find (toolbar), text, priv->links_only);
 
 	found = result != GALEON_EMBED_FIND_NOTFOUND;
 	set_status (toolbar, result);
-#endif
 	set_controls (toolbar, found, found);
 }
 
@@ -631,11 +624,9 @@ galeon_find_toolbar_set_embed (GaleonFindToolbar *toolbar,
 		g_signal_connect_object (embed, "ge-content-change",
 					 G_CALLBACK (tab_content_changed_cb),
 					 toolbar, G_CONNECT_AFTER);
-#ifdef HAVE_TYPEAHEADFIND
 		g_signal_connect_object (embed, "ge-search-key-press",
 					 G_CALLBACK (tab_search_key_press_cb),
 					 toolbar, 0);
-#endif /* HAVE_TYPEAHEADFIND */
 
 		if (priv->find != NULL)
 		{
