@@ -870,8 +870,8 @@ galeon_popup_class_init (GaleonPopupClass *klass)
 
 	g_object_class_install_property (object_class,
                                          PROP_WINDOW,
-                                         g_param_spec_object ("GaleonWindow",
-                                                              "GaleonWindow",
+                                         g_param_spec_object ("window",
+                                                              "window",
                                                               "Parent window",
                                                               GALEON_TYPE_WINDOW,
                                                               G_PARAM_READWRITE |
@@ -886,7 +886,7 @@ galeon_popup_class_init (GaleonPopupClass *klass)
                                                               G_PARAM_READWRITE ));
 
 	g_object_class_install_property (object_class,
-                                         PROP_EVENT,
+                                         PROP_EMBED,
                                          g_param_spec_object ("embed",
                                                               "embed",
                                                               "Attached embed",
@@ -903,7 +903,7 @@ galeon_popup_new(GaleonWindow *window)
 	GaleonPopup *p;
 	
         p = g_object_new (GALEON_TYPE_POPUP, 
-			  "GaleonWindow", window,
+			  "window", window,
 			  NULL);
 	
         return p;
