@@ -15,19 +15,27 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "history-dialog.h"
-#include "galeon-shell.h"
+
 #include "galeon-embed-shell.h"
-#include "gul-string.h"
-#include "gul-gui.h"
 #include "galeon-dnd.h"
+#include "galeon-shell.h"
+#include "galeon-window.h"
+#include "gul-gui.h"
+#include "gul-string.h"
+#include "gul-state.h"
 #include "location-entry.h"
+#include "galeon-debug.h"
 
 #include <gtk/gtktreeview.h>
 #include <gtk/gtktreestore.h>
+#include <gtk/gtktreeselection.h>
 #include <gtk/gtkcellrenderertext.h>
-#include <bonobo/bonobo-i18n.h>
+#include <glib/gi18n.h>
 
 #define CONF_HISTORY_SEARCH_TEXT "/apps/galeon/Browsing/History/search_text"
 #define CONF_HISTORY_SEARCH_TIME "/apps/galeon/Browsing/History/search_time"
@@ -39,14 +47,13 @@ static void history_dialog_finalize (GObject *object);
 static void history_dialog_set_embedded (HistoryDialog *d,
 			     	         gboolean embedded);
 
-
 /* Glade callbacks */
 void
 history_host_checkbutton_toggled_cb (GtkWidget *widget, 
 				     HistoryDialog *dialog);
 void
-history_time_optionmenu_changed_cb (GtkWidget *widget, 
-			            HistoryDialog *dialog);
+history_time_combobox_changed_cb (GtkWidget *widget, 
+				  HistoryDialog *dialog);
 void
 history_entry_changed_cb (GtkWidget *widget, 
 			  HistoryDialog *dialog);
@@ -60,6 +67,10 @@ history_clear_button_clicked_cb (GtkWidget *button,
 
 static GObjectClass *parent_class = NULL;
 
+#define HISTORY_DIALOG_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), \
+				       TYPE_HISTORY_DIALOG, HistoryDialogPrivate))
+
+
 struct HistoryDialogPrivate
 {
 	GlobalHistory *gh;
@@ -68,8 +79,11 @@ struct HistoryDialogPrivate
 	HistoryFilter filter;
 	gboolean group;
 	gboolean embedded;
+	guint filter_entry_timeout;
 };
 
+#define FILTER_ENTRY_TIMEOUT 700
+
 enum
 {
 	PROP_0,
@@ -78,6 +92,7 @@ enum
 
 enum
 {
+	PROP_DIALOG,
 	PROP_TREEVIEW,
 	PROP_WORD,
 	PROP_TIME,
@@ -94,9 +109,10 @@ static GtkTargetEntry url_drag_types [] =
 static const
 GaleonDialogProperty properties [] =
 {
+	{ PROP_DIALOG, "history_dialog", NULL, PT_NORMAL, NULL },
 	{ PROP_TREEVIEW, "history_treeview", NULL, PT_NORMAL, NULL },
 	{ PROP_WORD, "history_entry", CONF_HISTORY_SEARCH_TEXT, PT_NORMAL, NULL },
-	{ PROP_TIME, "history_time_optionmenu", CONF_HISTORY_SEARCH_TIME, PT_NORMAL, NULL },
+	{ PROP_TIME, "history_time_combobox", CONF_HISTORY_SEARCH_TIME, PT_NORMAL, NULL },
 	{ PROP_GROUP, "history_host_checkbutton", CONF_HISTORY_HOST_GROUP, PT_NORMAL, NULL },
 	{ -1, NULL, NULL }
 };
@@ -121,7 +137,7 @@ history_dialog_get_type (void)
                         (GInstanceInitFunc) history_dialog_init
                 };
 
-                history_dialog_type = g_type_register_static (GALEON_EMBED_DIALOG_TYPE,
+                history_dialog_type = g_type_register_static (GALEON_TYPE_EMBED_DIALOG,
 						              "HistoryDialog",
 						              &our_info, 0);
         }
@@ -182,6 +198,8 @@ history_dialog_class_init (HistoryDialogClass *klass)
                                                                "Show embedded in another widget",
                                                                TRUE,
                                                                G_PARAM_READWRITE));
+
+	g_type_class_add_private (klass, sizeof (HistoryDialogPrivate));
 }
 
 static void
@@ -191,15 +209,14 @@ history_dialog_row_activated_cb (GtkTreeView *tree_view, GtkTreePath *path,
 	GaleonEmbed *embed;
         GtkTreeIter iter;
         GtkTreeModel *model = gtk_tree_view_get_model (tree_view);
-        GValue val = {0, };
-        const char *url;
+        char *url;
 
         gtk_tree_model_get_iter (model, &iter, path);
-        gtk_tree_model_get_value (model, &iter, 1, &val);
-        url = g_value_get_string (&val);
+        gtk_tree_model_get (model, &iter, 1, &url, -1);
 
 	embed = galeon_embed_dialog_get_embed (GALEON_EMBED_DIALOG(dialog));
 	galeon_embed_load_url (embed, url);
+	g_free (url);
 }
 
 static void
@@ -214,8 +231,7 @@ each_url_get_data_binder (GaleonDragEachSelectedItemDataGet iteratee,
 	
 	for (l = refs; l != NULL; l = l->next)
 	{
-		GValue val = {0, };
-        	const char *url;
+        	char *url, *title;
 		GtkTreeIter iter;
                 GtkTreePath *path;
 
@@ -224,9 +240,15 @@ each_url_get_data_binder (GaleonDragEachSelectedItemDataGet iteratee,
                 gtk_tree_model_get_iter 
                         (model, &iter, path);
 
-		gtk_tree_model_get_value (model, &iter, 1, &val);
-	        url = g_value_get_string (&val);
-		iteratee (url, -1, -1, -1, -1, data);
+		gtk_tree_model_get (model, &iter, 
+				    0, &title,
+				    1, &url,
+				    -1);
+
+		iteratee (url, title, -1, -1, -1, -1, data);
+
+		g_free (url);
+		g_free (title);
 	}
 
 	gul_gui_treeview_free_selection_refs (refs);
@@ -257,13 +279,15 @@ history_dialog_setup_view (HistoryDialog *dialog)
 	GtkTreeSelection *selection;
 
 	/* set tree model */
-        treestore = gtk_tree_store_new (6,
+        treestore = gtk_tree_store_new (8,
                                         G_TYPE_STRING,
                                         G_TYPE_STRING,
                                         G_TYPE_STRING,
                                         G_TYPE_STRING,
                                         G_TYPE_INT,
-					G_TYPE_POINTER);
+					G_TYPE_POINTER,
+					G_TYPE_INT,
+					G_TYPE_INT);
         dialog->priv->model = GTK_TREE_MODEL(treestore);
         gtk_tree_view_set_model (treeview, 
                                  GTK_TREE_MODEL (treestore));
@@ -295,7 +319,7 @@ history_dialog_setup_view (HistoryDialog *dialog)
         column = gtk_tree_view_get_column (treeview, 0);
         gtk_tree_view_column_set_resizable (column, TRUE);
         gtk_tree_view_column_set_reorderable (column, TRUE);
-	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+	gtk_tree_view_column_set_min_width (column, 20);
 	gtk_tree_view_column_set_max_width (column, 400);
         gtk_tree_view_column_set_sort_column_id (column, 0);
 
@@ -307,7 +331,7 @@ history_dialog_setup_view (HistoryDialog *dialog)
         column = gtk_tree_view_get_column (treeview, 1);
         gtk_tree_view_column_set_resizable (column, TRUE);
         gtk_tree_view_column_set_reorderable (column, TRUE);
-	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+	gtk_tree_view_column_set_min_width (column, 20);
 	gtk_tree_view_column_set_max_width (column, 500);
         gtk_tree_view_column_set_sort_column_id (column, 1);
 
@@ -319,7 +343,7 @@ history_dialog_setup_view (HistoryDialog *dialog)
         column = gtk_tree_view_get_column (treeview, 2);
         gtk_tree_view_column_set_resizable (column, TRUE);
         gtk_tree_view_column_set_reorderable (column, TRUE);
-        gtk_tree_view_column_set_sort_column_id (column, 2);
+        gtk_tree_view_column_set_sort_column_id (column, 6);
 
         gtk_tree_view_insert_column_with_attributes (treeview,
                                                      3, _("First visited"),
@@ -329,7 +353,7 @@ history_dialog_setup_view (HistoryDialog *dialog)
         column = gtk_tree_view_get_column (treeview, 3);
         gtk_tree_view_column_set_resizable (column, TRUE);
         gtk_tree_view_column_set_reorderable (column, TRUE);
-        gtk_tree_view_column_set_sort_column_id (column, 3);
+        gtk_tree_view_column_set_sort_column_id (column, 7);
 
         gtk_tree_view_insert_column_with_attributes (treeview,
                                                      4, _("Times visited"),
@@ -363,6 +387,8 @@ history_dialog_update_host_item (HistoryDialog *dialog,
                             3, text[3],
                             4, item->visits,
 			    5, item,
+			    6, item->last,
+			    7, item->first,
                             -1);
 }
 
@@ -417,6 +443,8 @@ history_dialog_update_url_item (HistoryDialog *dialog,
                             3, text[3],
                             4, item->visits,
 			    5, item,
+			    6, item->last,
+			    7, item->first,
                             -1);
 }
 
@@ -471,6 +499,11 @@ history_dialog_fill_view (HistoryDialog *dialog)
 							     item);
 			history_dialog_add_url_items (dialog, urls, iter);
 			g_list_free (urls);
+
+			if (iter)
+			{
+				gtk_tree_iter_free (iter);
+			}
 		}
 	}
 
@@ -491,6 +524,8 @@ history_dialog_setup_filter (HistoryDialog *dialog)
 	GValue time = {0, };
 
 	galeon_dialog_get_value (GALEON_DIALOG(dialog), PROP_WORD, &word);
+	/* The cast is ok as we put the string in there using g_value_get_string */
+	g_free ( (char*)dialog->priv->filter.word);
         dialog->priv->filter.word = g_value_get_string (&word);
 	
 	galeon_dialog_get_value (GALEON_DIALOG(dialog), PROP_TIME, &time);
@@ -506,20 +541,19 @@ history_dialog_find_host_iter (HistoryDialog *dialog,
 {
 	GtkTreeIter iter;
 	
-	gtk_tree_model_get_iter (dialog->priv->model,
-				 &iter,
-				 gtk_tree_path_new_first());
-	
-	do
+	if (gtk_tree_model_get_iter (dialog->priv->model, &iter,
+				     gtk_tree_path_new_first()) == TRUE)
 	{
-		GValue val = { 0, }; 
-		HistoryItem *i;
-		gtk_tree_model_get_value (dialog->priv->model, 
-					  &iter, 5, &val);
-		i = (HistoryItem *) g_value_get_pointer (&val);
-		if (i == item) return gtk_tree_iter_copy (&iter); 
+		do {
+			GValue val = { 0, }; 
+			HistoryItem *i;
+			gtk_tree_model_get_value (dialog->priv->model, 
+						  &iter, 5, &val);
+			i = (HistoryItem *) g_value_get_pointer (&val);
+			if (i == item) return gtk_tree_iter_copy (&iter); 
+		}
+		while (gtk_tree_model_iter_next (dialog->priv->model, &iter));
 	}
-	while (gtk_tree_model_iter_next (dialog->priv->model, &iter));
 
 	return NULL;
 }
@@ -577,11 +611,12 @@ history_item_add_cb (GlobalHistory *gh,
 						     host);
 	}
 
-	g_return_if_fail (iter != NULL);
-
 	history_dialog_add_url_item (dialog, item, iter);
-	
-	gtk_tree_iter_free (iter);
+
+	if (iter)
+	{
+		gtk_tree_iter_free (iter);
+	}
 }
 
 static void
@@ -655,7 +690,7 @@ history_dialog_init (HistoryDialog *dialog)
 {	
 	GaleonEmbedShell *ges;
 	
-	dialog->priv = g_new0 (HistoryDialogPrivate, 1);
+	dialog->priv = HISTORY_DIALOG_GET_PRIVATE (dialog);
 
 	ges = galeon_shell_get_embed_shell (galeon_shell);
 	dialog->priv->gh = galeon_embed_shell_get_global_history (ges);
@@ -687,7 +722,15 @@ history_dialog_set_embedded (HistoryDialog *dialog,
 				 embedded ? 
 				 "history_dock_box" :
 				 "history_dialog");
-	
+
+	if (!embedded)
+	{
+		gul_state_monitor_window (
+			galeon_dialog_get_control (GALEON_DIALOG(dialog),
+				                   PROP_DIALOG),
+			"History", -1, -1);
+	}
+
 	dialog->priv->treeview = GTK_TREE_VIEW (
 				 galeon_dialog_get_control (GALEON_DIALOG(dialog), 
 							    PROP_TREEVIEW));
@@ -700,28 +743,38 @@ static void
 history_dialog_finalize (GObject *object)
 {
 	HistoryDialog *dialog;
+	HistoryDialogPrivate *p;
 
         g_return_if_fail (object != NULL);
         g_return_if_fail (IS_HISTORY_DIALOG (object));
 
 	dialog = HISTORY_DIALOG (object);
+	p = dialog->priv;
 
         g_return_if_fail (dialog->priv != NULL);
 
+	if (p->filter_entry_timeout)
+	{
+		g_source_remove (p->filter_entry_timeout);
+	}
+
 	g_signal_handlers_disconnect_by_func 
-		(G_OBJECT(dialog->priv->gh),
+		(G_OBJECT(p->gh),
 		 G_CALLBACK (history_item_add_cb),
 		 dialog);
 	g_signal_handlers_disconnect_by_func 
-		(G_OBJECT(dialog->priv->gh),
+		(G_OBJECT(p->gh),
 		 G_CALLBACK (history_item_update_cb),
 		 dialog);
 	g_signal_handlers_disconnect_by_func 
-		(G_OBJECT(dialog->priv->gh),
+		(G_OBJECT(p->gh),
 		 G_CALLBACK (history_item_remove_cb),
 		 dialog);
+
+	g_object_unref (p->model);
 	
-        g_free (dialog->priv);
+	/* The cast is ok as we put the string in there using g_value_get_string */
+	g_free ((char*)p->filter.word);
 
         G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -732,7 +785,7 @@ history_dialog_new (GaleonEmbed *embed,
 {
 	HistoryDialog *dialog;
 	
-	dialog = HISTORY_DIALOG (g_object_new (HISTORY_DIALOG_TYPE,
+	dialog = HISTORY_DIALOG (g_object_new (TYPE_HISTORY_DIALOG,
 					       "embedded", embedded,
 				     	       "GaleonEmbed", embed,
 				               NULL));
@@ -747,7 +800,7 @@ history_dialog_new_with_parent (GtkWidget *window,
 {
 	HistoryDialog *dialog;
 	
-	dialog = HISTORY_DIALOG (g_object_new (HISTORY_DIALOG_TYPE,
+	dialog = HISTORY_DIALOG (g_object_new (TYPE_HISTORY_DIALOG,
 					       "embedded", embedded,
 				     	       "GaleonEmbed", embed,
 				     	       "ParentWindow", window,
@@ -766,19 +819,54 @@ history_host_checkbutton_toggled_cb (GtkWidget *widget,
 	history_dialog_fill_view (dialog);
 }
 
+static gboolean
+history_filter_entry_timeout_cb (gpointer data)
+{
+	HistoryDialog *dialog = data;
+	HistoryDialogPrivate *p = dialog->priv;
+
+	p->filter_entry_timeout = 0;
+
+	START_PROFILER ("Clear liststore");
+
+	history_dialog_clear_view (dialog);
+
+	STOP_PROFILER ("Clear liststore");
+	START_PROFILER ("Setting filter");
+
+	history_dialog_setup_filter (dialog);
+
+	STOP_PROFILER ("Setting filter");
+	START_PROFILER ("Filling view");
+
+	history_dialog_fill_view (dialog);
+
+	STOP_PROFILER ("Filling view");
+
+	return FALSE;
+}
+
+
 void
 history_entry_changed_cb (GtkWidget *widget, 
 			  HistoryDialog *dialog)
 {
-	if (dialog->priv->treeview == NULL) return;
-	history_dialog_clear_view (dialog);
-	history_dialog_setup_filter (dialog);
-	history_dialog_fill_view (dialog);
+	HistoryDialogPrivate *p = dialog->priv;
+
+	if (p->treeview == NULL) return;
+
+	if (p->filter_entry_timeout)
+	{
+		g_source_remove (p->filter_entry_timeout);
+	}
+	
+	p->filter_entry_timeout = g_timeout_add (FILTER_ENTRY_TIMEOUT, 
+						 history_filter_entry_timeout_cb, dialog);
 }
 
 void
-history_time_optionmenu_changed_cb (GtkWidget *widget, 
-			            HistoryDialog *dialog)
+history_time_combobox_changed_cb (GtkWidget *widget, 
+				  HistoryDialog *dialog)
 {
 	if (dialog->priv->treeview == NULL) return;
 	history_dialog_clear_view (dialog);
@@ -797,8 +885,20 @@ void
 history_clear_button_clicked_cb (GtkWidget *button,
 			         HistoryDialog *dialog)
 {
+	Session * session;
+	const GList *windows;
+	const GList *win;
+
 	history_dialog_clear_view (dialog);
 	global_history_clear (dialog->priv->gh);
 	galeon_location_entry_clear_history ();
+
+	session = galeon_shell_get_session (galeon_shell);
+	windows = session_get_windows (session);
+
+	for (win = windows; win ; win = win->next)
+	{
+		galeon_window_clear_history (win->data);
+	} 
 }
 
