@@ -27,6 +27,11 @@
 
 
 G_BEGIN_DECLS
+
+void             gul_gui_sanitise_popup_position (GtkMenu *menu,
+						  GtkWidget *widget,
+						  gint *x,
+						  gint *y);
 	
 void 		 gul_gui_menu_position_under_widget 	(GtkMenu   *menu,
 					  		 gint      *x,
@@ -34,6 +39,12 @@ void 		 gul_gui_menu_position_under_widget 	(GtkMenu   *menu,
 					  		 gboolean  *push_in,
 					  		 gpointer  user_data);
 
+void             gul_gui_menu_position_tree_selection    (GtkMenu   *menu,
+                                                          gint      *x,
+                                                          gint      *y,
+                                                          gboolean  *push_in,
+                                                          gpointer  user_data);
+
 gint 		 gul_gui_gtk_radio_button_get 		(GtkRadioButton *radio_button);
 
 void 		 gul_gui_gtk_radio_button_set 		(GtkRadioButton *radio_button, 
@@ -72,6 +83,9 @@ gboolean	gul_gui_confirm_overwrite_file	       (GtkWidget *parent,
 
 gboolean	gul_gui_widget_hide_now		       (GtkWidget *widget);
 
+void            gul_gui_window_present                 (GtkWindow *widget,
+							guint32 user_time);
+
 void		gul_gui_setup_tearoff		       (GtkMenuShell *ms);
 void		gul_gui_add_separator_conditional      (GtkMenuShell *ms);
 void		gul_gui_remove_separator_conditional   (GtkMenuShell *ms);
@@ -81,6 +95,10 @@ void            gul_gui_image_set_from_mime_type       (GtkWidget  *image,
 		                                        const char *mime_type,
 							GtkIconSize icon_size);
 
+
+GtkWidget *     gul_gui_image_button_new               (const char *label_text,
+							const char *image_stock_id);
+
 void            gul_gui_help                           (GtkWindow* parent,
 							const char *file,
 							const char *link_id);
