@@ -131,14 +131,16 @@ gul_pixbuf_cache_register_stocks (void)
 	gint i;
 
 	GtkStockItem items[] = {
-		{ GALEON_STOCK_BOOKMARK      ,"_Bookmark",   0, 0, NULL },
 		{ GALEON_STOCK_SEPARATOR     ,"_Separator",  0, 0, NULL },
 		{ GALEON_STOCK_FOLDER        ,"_Folder",     0, 0, NULL },
 		{ GALEON_STOCK_DEFAULT       ,"_Default",    0, 0, NULL },
 		{ GALEON_STOCK_HISTORY       ,"_History",    0, 0, NULL },
+		{ GALEON_STOCK_FILTER        ,"_Filter",     0, 0, NULL },
 		{ GALEON_STOCK_POPUP_BLOCKED ,"_Popup blocked", 0, 0, NULL },
 		{ GALEON_STOCK_SECURE        ,"_Secure",      0, 0, NULL },
-		{ GALEON_STOCK_INSECURE      ,"_Insecure",    0, 0, NULL }
+		{ GALEON_STOCK_INSECURE      ,"_Insecure",    0, 0, NULL },
+		{ GALEON_STOCK_DOWNLOAD      ,"_Download",    0, 0, NULL },
+		{ GALEON_STOCK_ENTRY         ,"_Entry",       0, 0, NULL }
 	};
 
 	const char * icon_theme_items[] = {
@@ -152,7 +154,8 @@ gul_pixbuf_cache_register_stocks (void)
 		STOCK_SELECT_ALL,
 		STOCK_EDIT_BOOKMARK,
 		STOCK_CONNECT,
-		STOCK_DISCONNECT
+		STOCK_DISCONNECT,
+		STOCK_LOCK_BROKEN
 	};
 
 
